import { useEffect, useState } from "react";

const useReducedMotion = (): boolean => {
	const [prefersReducedMotion, setPrefersReducedMotion] =
		useState<boolean>(false);

	useEffect(() => {
		if (typeof window === "undefined") {
			return;
		}

		const mediaQuery = window.matchMedia("(prefers-reduced-motion: reduce)");
		setPrefersReducedMotion(mediaQuery.matches);

		const handleMotionPreferenceChange = (event: MediaQueryListEvent) => {
			setPrefersReducedMotion(event.matches);
		};

		mediaQuery.addEventListener("change", handleMotionPreferenceChange);

		return () => {
			mediaQuery.removeEventListener("change", handleMotionPreferenceChange);
		};
	}, []);

	return prefersReducedMotion;
};

export default useReducedMotion;
